@@ -1,9 +1,10 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2018 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Evgeny Mandrikov - initial API and implementation
@@ -11,20 +12,16 @@
  *******************************************************************************/
 package org.jacoco.core.internal.analysis.filter;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
-
-import java.util.ArrayList;
-import java.util.List;
-
 import org.jacoco.core.internal.instr.InstrSupport;
 import org.junit.Test;
 import org.objectweb.asm.Label;
 import org.objectweb.asm.Opcodes;
-import org.objectweb.asm.tree.AbstractInsnNode;
 import org.objectweb.asm.tree.MethodNode;
 
-public class TryWithResourcesJavacFilterTest implements IFilterOutput {
+/**
+ * Unit tests for {@link TryWithResourcesJavacFilter}.
+ */
+public class TryWithResourcesJavacFilterTest extends FilterTestBase {
 
 	private final TryWithResourcesJavacFilter filter = new TryWithResourcesJavacFilter();
 
@@ -219,26 +216,14 @@ public class TryWithResourcesJavacFilterTest implements IFilterOutput {
 		m.visitVarInsn(Opcodes.ALOAD, 8);
 		m.visitInsn(Opcodes.ATHROW);
 
-		filter.filter("Foo", "java/lang/Object", m, this);
+		filter.filter(m, context, output);
 
-		assertEquals(4, from.size());
-
-		assertEquals(range0.fromInclusive, from.get(0));
-		assertEquals(range0.toInclusive, to.get(0));
-
-		assertEquals(range1.fromInclusive, from.get(1));
-		assertEquals(range1.toInclusive, to.get(1));
-
-		assertEquals(range2.fromInclusive, from.get(2));
-		assertEquals(range2.toInclusive, to.get(2));
-
-		assertEquals(range3.fromInclusive, from.get(3));
-		assertEquals(range3.toInclusive, to.get(3));
+		assertIgnored(range0, range1, range2, range3);
 	}
 
 	/**
 	 * javac 7 and 8 for
-	 * 
+	 *
 	 * <pre>
 	 *     try (r0 = ...; r1 = ...) {
 	 *         return ...
@@ -548,26 +533,14 @@ public class TryWithResourcesJavacFilterTest implements IFilterOutput {
 		m.visitVarInsn(Opcodes.ALOAD, 11);
 		m.visitInsn(Opcodes.ATHROW);
 
-		filter.filter("Foo", "java/lang/Object", m, this);
+		filter.filter(m, context, output);
 
-		assertEquals(4, from.size());
-
-		assertEquals(range0.fromInclusive, from.get(0));
-		assertEquals(range0.toInclusive, to.get(0));
-
-		assertEquals(range1.fromInclusive, from.get(1));
-		assertEquals(range1.toInclusive, to.get(1));
-
-		assertEquals(range2.fromInclusive, from.get(2));
-		assertEquals(range2.toInclusive, to.get(2));
-
-		assertEquals(range3.fromInclusive, from.get(3));
-		assertEquals(range3.toInclusive, to.get(3));
+		assertIgnored(range0, range1, range2, range3);
 	}
 
 	/**
 	 * javac 9 for
-	 * 
+	 *
 	 * <pre>
 	 *     try (r = new ...) {
 	 *         ...
@@ -726,20 +699,14 @@ public class TryWithResourcesJavacFilterTest implements IFilterOutput {
 
 		m.visitLabel(end);
 
-		filter.filter("Foo", "java/lang/Object", m, this);
+		filter.filter(m, context, output);
 
-		assertEquals(2, from.size());
-
-		assertEquals(range0.fromInclusive, from.get(0));
-		assertEquals(range0.toInclusive, to.get(0));
-
-		assertEquals(range1.fromInclusive, from.get(1));
-		assertEquals(range1.toInclusive, to.get(1));
+		assertIgnored(range0, range1);
 	}
 
 	/**
 	 * javac 9 for
-	 * 
+	 *
 	 * <pre>
 	 *     try (r = new ...) {
 	 *       throw ...
@@ -794,26 +761,9 @@ public class TryWithResourcesJavacFilterTest implements IFilterOutput {
 		m.visitVarInsn(Opcodes.ALOAD, 4);
 		m.visitInsn(Opcodes.ATHROW);
 
-		filter.filter("Foo", "java/lang/Object", m, this);
+		filter.filter(m, context, output);
 
-		assertEquals(0, from.size());
-	}
-
-	static class Range {
-		AbstractInsnNode fromInclusive;
-		AbstractInsnNode toInclusive;
-	}
-
-	private final List<AbstractInsnNode> from = new ArrayList<AbstractInsnNode>();
-	private final List<AbstractInsnNode> to = new ArrayList<AbstractInsnNode>();
-
-	public void ignore(AbstractInsnNode from, AbstractInsnNode to) {
-		this.from.add(from);
-		this.to.add(to);
-	}
-
-	public void merge(final AbstractInsnNode i1, final AbstractInsnNode i2) {
-		fail();
+		assertIgnored();
 	}
 
 }
