@@ -1,9 +1,10 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2018 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Evgeny Mandrikov - initial API and implementation
@@ -14,8 +15,8 @@ package org.jacoco.core.internal.analysis.filter;
 import org.objectweb.asm.tree.MethodNode;
 
 /**
- * Interface for filter implementations. Instances of filters are reused and so
- * must be stateless.
+ * Interface for filter implementations. Instances of filters are created for
+ * analysis of each class and so can have per-class state.
  */
 public interface IFilter {
 
@@ -24,16 +25,13 @@ public interface IFilter {
 	 * expected to inspect the provided method and report its result to the
 	 * given {@link IFilterOutput} instance.
 	 *
-	 * @param className
-	 *            class name
-	 * @param superClassName
-	 *            superclass name
 	 * @param methodNode
 	 *            method to inspect
+	 * @param context
+	 *            context information for the method
 	 * @param output
 	 *            callback to report filtering results to
 	 */
-	void filter(String className, String superClassName, MethodNode methodNode,
+	void filter(MethodNode methodNode, IFilterContext context,
 			IFilterOutput output);
-
 }
