@@ -1,9 +1,10 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2018 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Evgeny Mandrikov - initial API and implementation
@@ -11,6 +12,8 @@
  *******************************************************************************/
 package org.jacoco.core.internal.analysis.filter;
 
+import java.util.Set;
+
 import org.objectweb.asm.tree.AbstractInsnNode;
 
 /**
@@ -33,7 +36,7 @@ public interface IFilterOutput {
 	/**
 	 * Marks two instructions that should be merged during computation of
 	 * coverage.
-	 * 
+	 *
 	 * @param i1
 	 *            first instruction
 	 * @param i2
@@ -41,4 +44,16 @@ public interface IFilterOutput {
 	 */
 	void merge(AbstractInsnNode i1, AbstractInsnNode i2);
 
+	/**
+	 * Marks instruction whose outgoing branches should be replaced during
+	 * computation of coverage.
+	 *
+	 * @param source
+	 *            instruction which branches should be replaced
+	 * @param newTargets
+	 *            new targets of branches
+	 */
+	void replaceBranches(AbstractInsnNode source,
+			Set<AbstractInsnNode> newTargets);
+
 }
