@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2018 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.core.runtime;
 
@@ -20,7 +21,7 @@ public interface IRemoteCommandVisitor {
 
 	/**
 	 * Requests a execution data dump with an optional reset.
-	 * 
+	 *
 	 * @param dump
 	 *            <code>true</code> if the dump should be executed
 	 * @param reset
@@ -28,7 +29,6 @@ public interface IRemoteCommandVisitor {
 	 * @throws IOException
 	 *             in case of problems with the remote connection
 	 */
-	public void visitDumpCommand(final boolean dump, final boolean reset)
-			throws IOException;
+	void visitDumpCommand(boolean dump, boolean reset) throws IOException;
 
 }
