@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2018 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.report;
 
@@ -22,21 +23,21 @@ public interface IMultiReportOutput {
 	/**
 	 * Creates a file at the given local path. The returned {@link OutputStream}
 	 * has to be closed before the next document is created.
-	 * 
+	 *
 	 * @param path
 	 *            local path to the new document
 	 * @return output for the content
 	 * @throws IOException
 	 *             if the creation fails
 	 */
-	public OutputStream createFile(String path) throws IOException;
+	OutputStream createFile(String path) throws IOException;
 
 	/**
 	 * Closes the underlying resource container.
-	 * 
+	 *
 	 * @throws IOException
 	 *             if closing fails
 	 */
-	public void close() throws IOException;
+	void close() throws IOException;
 
 }
