@@ -1,13 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2018 Mountainminds GmbH & Co. KG and Contributors
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * This program and the accompanying materials are made available under
+ * the terms of the Eclipse Public License 2.0 which is available at
+ * http://www.eclipse.org/legal/epl-2.0
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Marc R. Hoffmann - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.jacoco.report.internal.html.index;
 
@@ -21,12 +22,12 @@ public interface IIndexUpdate {
 
 	/**
 	 * Adds a class to the index.
-	 * 
+	 *
 	 * @param link
 	 *            link to the class
 	 * @param classid
 	 *            identifier of the class
 	 */
-	public void addClass(ILinkable link, long classid);
+	void addClass(ILinkable link, long classid);
 
 }
